/* This file is part of "Heuristics for SONET network design".
   See COPYRIGHT and LICENSE files for details.

   This file, as the whole "Heuristics for SONET network design"
   package, is released under the GNU GPL License.  
   Copyright (C) Pierre Lemaire, 2001.
*/

/* output:
 * filename ; c ; B1 ; B2 ; B3
 */
#include <stdlib.h>
#include <iostream.h>
#include <math.h>
#include "list.hpp"
#include "datareader.hpp"

#define MAX(A, B) ((A) > (B) ? (A) : (B))

int main(int argc, char * argv[])
{ char* infilename = NULL;
  int c = -1;

  // --------------------------------------------------------------------------
  // gets parameters
  --argc; ++argv;
  while (argc >= 1)
  { if (strcmp(*argv,"-h") == 0)
    { cout << "--------------------------------------" << endl
           << "usage: bounds [options] filename" << endl
           << "  -h         : this help" << endl
           << "  -c int     : capacity of a ring" << endl;
      }
    else if (strcmp(*argv, "-c")==0)
    { --argc; ++argv;
      if (argc <= 0){ cerr << "option -c requires a value" << endl; exit(1); }
      c = atoi(*argv);
      }
    else // this is the input file name
    { infilename = *(argv);
      }
    --argc; ++argv;
    }
  // --------------------------------------------------------------------------
  // checks parameters
  if (infilename == NULL)
  { cerr << "An input file must be precised" << endl;
    exit(1);
    }
  if (c < 1)
  { cerr << "The capacity of a ring must be a positif integer"
         << endl;
    exit(1);
    }
  // --------------------------------------------------------------------------
  DataReader data(infilename);
  List<Edge> *edges = new List<Edge>;
  Edge *edge;
  int m = 0;
  int n = 0;
  int *d;
  double B1, B2, B3;
  int i;

  // ------- Auxilary required values -------
  // reads data, calculates m and n
  while((edge = data.getEdge()) != NULL)
  { if (edge->demand > c){ cerr << "No feasible solution." << endl; exit(1); }
    edges->add(edge);
    m++;
    n = MAX(n,MAX(edge->node[0],edge->node[1]));
    }

  // calculates degrees
  d = new int[n]; for(i=0; i<n; i++) d[i] = 0;
  edge = edges->head;
  while((edge = edge->succ) != edges->tail)
  { d[edge->node[0]-1]++;
    d[edge->node[1]-1]++;
    }

  // ------- Calculates bounds -------
  // B1
  B1 = ceil(sqrt(2.0 / c) * m);

  // B2
  B2 = ceil(ceil((1.0+sqrt(1.0+8*c)) / 2.0) * m / c);

  // B3
  B3 = 0; for(i=0; i<n; i++) B3 += ceil(((float) d[i]) / c);

 
  cout << infilename << " ; " << c << " ; "
       << B1 << " ; " << B2 << " ; " << B3
       << endl;
  return 0;
  }
