/* This file is part of "Heuristics for SONET network design".
   See COPYRIGHT and LICENSE files for details.

   This file, as the whole "Heuristics for SONET network design"
   package, is released under the GNU GPL License.  
   Copyright (C) Pierre Lemaire, 2001.
*/

#include <time.h>
#include <stdlib.h>
#include <iostream.h>

int main(int argc, char * argv[])
{ int n = -1;  // max number of nodes
  int L = 1;
  int l = 1;  

  // --------------------------------------------------------------------------
  // gets parameters
  --argc; ++argv;
  while (argc >= 1)
  { if (strcmp(*argv,"-h") == 0)
    { cout << "--------------------------------------" << endl
           << "usage: geographic [options]" << endl
           << "  -h         : this help" << endl
           << "  -n int     : number of nodes" << endl
           << "  -L int     : side-length of the repartition-square" << endl
           << "  -l int     : max. distance for connecting" << endl;
      }
    else if (strcmp(*argv, "-n")==0)
    { --argc; ++argv;
      if (argc <= 0){ cerr << "option -n requires a value" << endl; exit(1); }
      n = atoi(*argv);
      }
    else if (strcmp(*argv, "-L")==0)
    { --argc; ++argv;
      if (argc <= 0){ cerr << "option -L requires a value" << endl; exit(1); }
      L = atoi(*argv);
      }
    else if (strcmp(*argv, "-l")==0)
    { --argc; ++argv;
      if (argc <= 0){ cerr << "option -l requires a value" << endl; exit(1); }
      l = atoi(*argv);
      }
    else
    { cerr << "unknown option: " << *argv << endl;
      }
    --argc; ++argv;
    }
  // --------------------------------------------------------------------------
  if (n < 1)
  { cerr << "Number of nodes (n) must be a positive integer" << endl;
    exit(1);
    }
  if (L < 1)
  { cerr << "Square-side (L) must be a positive integer" << endl;
    exit(1);
    }
  if (l < 1)
  { cerr << "connecting-distance (l) must be a positive integer" << endl;
    exit(1);
    }
  // --------------------------------------------------------------------------
  int *x, *y;
  int i,j,d;
  const int l2 = l*l;

  srand(time(0)); // initialisation du generateur aleatoire

  x = new int[n];
  y = new int[n];
  for(i=0; i<n; i++){ x[i] = rand()%L; y[i] = rand()%L; }

  for(i=0; i<n-1; i++) for(j=i+1; j<n; j++)
    if (((x[i]-x[j])*(x[i]-x[j]) + (y[i]-y[j])*(y[i]-y[j])) <= l2)
    { cout << i << ":" << j << ",";
      d = rand()%100;
      if (d <= 64) cout << 1 << endl;
      else if (d <= 96) cout << 2 << endl;
      else cout << 3 << endl;
      }

  return 0;
  }
