/* This file is part of "Heuristics for SONET network design".
   See COPYRIGHT and LICENSE files for details.

   This file, as the whole "Heuristics for SONET network design"
   package, is released under the GNU GPL License.  
   Copyright (C) Pierre Lemaire, 2001.
*/

#include <time.h>
#include <stdlib.h>
#include <iostream.h>
#include "edge.hpp"

int main(int argc, char * argv[])
{ int n = -1; // max number of nodes
  int d = -1; // demand max

  // --------------------------------------------------------------------------
  // gets parameters
  --argc; ++argv;
  while (argc >= 1)
  { if (strcmp(*argv,"-h") == 0)
    { cout << "--------------------------------------" << endl
           << "usage: randtree [options]" << endl
           << "  -h         : this help" << endl
           << "  -n int     : number of nodes" << endl
           << "  -d int     : maximum value of a demand" << endl;
      }
    else if (strcmp(*argv, "-n")==0)
    { --argc; ++argv;
      if (argc <= 0){ cerr << "option -n requires a value" << endl; exit(1); }
      n = atoi(*argv);
      }
    else if (strcmp(*argv, "-d")==0)
    { --argc; ++argv;
      if (argc <= 0){ cerr << "option -d requires a value" << endl; exit(1); }
      d = atoi(*argv);
      }
    else
    { cerr << "unknown option: " << *argv << endl;
      }
    --argc; ++argv;
    }
  // --------------------------------------------------------------------------
  if (n < 1)
  { cerr << "Number of nodes (n) must be a positive integer" << endl;
    exit(1);
    }
  if (d < 1)
  { cerr << "Maximum demand (d) must be a positive integer" << endl;
    exit(1);
    }
  // --------------------------------------------------------------------------
  int i,k;
  Edge* edge = NULL;
  Edge* tmp = NULL;
  srand(time(0)); // initialisation du generateur aleatoire
  // build a graph
  for(i=1; i<n; i++)
  { tmp = new Edge(rand()%i +1,i+1,rand()%d +1);
    // add it to the list of edges;
    if (edge == NULL) {edge = tmp; edge->succ = edge;}
    else
    { k = rand() % i;
      while(k >= 0){ edge = edge->succ; k--; }
      tmp->succ = edge->succ;
      edge->succ = tmp;
      }
    }

  // writes the loop of edges on stdout
  tmp = edge;
  do
  { cout << tmp->node[0] << ":" << tmp->node[1] << "," << tmp->demand << endl;
    tmp = tmp->succ;
    }while(tmp != edge);

  return 0;
  }
