/* This file is part of "Heuristics for SONET network design".
   See COPYRIGHT and LICENSE files for details.

   This file, as the whole "Heuristics for SONET network design"
   package, is released under the GNU GPL License.  
   Copyright (C) Pierre Lemaire, 2001.
*/

#include <time.h>
#include <stdlib.h>
#include <iostream.h>

int main(int argc, char * argv[])
{ int n = -1;  // max number of nodes
  int D = -1;  // approx. sum of demands

  // --------------------------------------------------------------------------
  // gets parameters
  --argc; ++argv;
  while (argc >= 1)
  { if (strcmp(*argv,"-h") == 0)
    { cout << "--------------------------------------" << endl
           << "usage: real [options]" << endl
           << "  -h         : this help" << endl
           << "  -n int     : number of nodes" << endl
           << "  -D int     : approx. sum of demands" << endl;
      }
    else if (strcmp(*argv, "-n")==0)
    { --argc; ++argv;
      if (argc <= 0){ cerr << "option -n requires a value" << endl; exit(1); }
      n = atoi(*argv);
      }
    else if (strcmp(*argv, "-D")==0)
    { --argc; ++argv;
      if (argc <= 0){ cerr << "option -D requires a value" << endl; exit(1); }
      D = atoi(*argv);
      }
    else
    { cerr << "unknown option: " << *argv << endl;
      }
    --argc; ++argv;
    }
  // --------------------------------------------------------------------------
  if (n < 1)
  { cerr << "Number of nodes (n) must be a positive integer" << endl;
    exit(1);
    }
  if (D < 1)
  { cerr << "Sum of demands (D) must be a positive integer" << endl;
    exit(1);
    }
  // --------------------------------------------------------------------------
  int i,j,d;
  int p = (int) (143*D/(n*(n-2)));
  
  srand(time(0)); // initialisation du generateur aleatoire

  for(i=1; i<=n; i++) for(j=i+1; j<=n; j++)
    if (rand() % 100 <= p)
    { cout << i << ":" << j << ",";
      d = rand()%100;
      if (d <= 64) cout << 1 << endl;
      else if (d <= 96) cout << 2 << endl;
      else cout << 3 << endl;
      }

  return 0;
  }
